.. _api_reference:

API Reference
===================

.. currentmodule:: shellplot

Figure API
-------------------

.. autosummary::
    :toctree: api/

    shellplot.figure

    shellplot.figure.Figure
    :noindex:
    :members:
    :undoc-members:

Plotting functions
-------------------

.. autosummary::
    :toctree: api/

    shellplot.plot
    shellplot.hist
    shellplot.barh
    shellplot.boxplot


Data loading
-------------------

.. autosummary::
    :toctree: api/

    shellplot.load_dataset
